@@ -22,7 +22,6 @@ from crispy_forms.layout import HTML, Div, Field, Fieldset, Layout, Submit
 from django import forms
 from django.contrib.auth import authenticate, password_validation
 from django.contrib.auth.forms import SetPasswordForm as DjangoSetPasswordForm
-from django.db.models import Q
 from django.middleware.csrf import rotate_token
 from django.utils.functional import cached_property
 from django.utils.html import escape
@@ -71,10 +70,17 @@ class UniqueEmailMixin:
         self.cleaned_data["email_user"] = None
         mail = self.cleaned_data["email"]
         users = User.objects.filter(
-            Q(social_auth__verifiedemail__email__iexact=mail) | Q(email=mail),
+            email=mail,
             is_active=True,
+            is_bot=False,
         )
-        if users.exists():
+        if not users:
+            users = User.objects.filter(
+                social_auth__verifiedemail__email__iexact=mail,
+                is_active=True,
+                is_bot=False,
+            )
+        if users:
             self.cleaned_data["email_user"] = users[0]
             if self.validate_unique_mail:
                 raise forms.ValidationError(
@@ -154,6 +160,12 @@ class LanguagesForm(ProfileBaseForm):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        # Remove empty choice from the form. We need it at the database level
+        # to initialize user profile, but it is filled in later based on
+        # languages configured in the browser.
+        self.fields["language"].choices = [
+            choice for choice in self.fields["language"].choices if choice[0]
+        ]
         # Limit languages to ones which have translation
         qs = Language.objects.have_translation()
         self.fields["languages"].queryset = qs
@@ -581,7 +593,7 @@ class LoginForm(forms.Form):
                 raise forms.ValidationError(
                     self.error_messages["invalid_login"], code="invalid_login"
                 )
-            if not self.user_cache.is_active:
+            if not self.user_cache.is_active or self.user_cache.is_bot:
                 raise forms.ValidationError(
                     self.error_messages["inactive"], code="inactive"
                 )
