@@ -31,3 +31,11 @@ class FileParseError(WeblateError):
 
 class PluralFormsMismatch(WeblateError):
     """Plural forms do not match the language."""
+
+
+class InvalidTemplate(WeblateError):
+    """Template file can not be parsed."""
+
+    def __init__(self, nested, message=None):
+        super().__init__(message or self.__doc__)
+        self.nested = nested
