@@ -386,6 +386,7 @@ class Translation(
         details["reason"] = self.reason
 
         self.log_info("processing %s, %s", self.filename, self.reason)
+        self.component.check_template_valid()
 
         # List of updated units (used for cleanup and duplicates detection)
         updated = {}
@@ -522,13 +523,12 @@ class Translation(
 
         if component.has_template():
             # Include template
-            filenames.append(component.template)
+            filenames.append(component.get_template_filename())
 
-            if component.intermediate and os.path.exists(
-                component.get_intermediate_filename()
-            ):
+            filename = component.get_intermediate_filename()
+            if component.intermediate and os.path.exists(filename):
                 # Include intermediate language as it might add new strings
-                filenames.append(component.intermediate)
+                filenames.append(filename)
 
         return filenames
 
@@ -546,7 +546,7 @@ class Translation(
         self.save(update_fields=["revision"])
 
     def get_last_author(self, email=False):
-        """Return last autor of change done in Weblate."""
+        """Return last author of change done in Weblate."""
         if not self.stats.last_author:
             return None
         from weblate.auth.models import User
@@ -709,7 +709,7 @@ class Translation(
                     # Bail out if we have not found anything
                     report_error(cause="String disappeared")
                     self.log_error(
-                        "string %s dissappeared from the file, removing", unit
+                        "string %s disappeared from the file, removing", unit
                     )
                     unit.delete()
                     continue
@@ -764,7 +764,7 @@ class Translation(
         if report_source_bugs:
             headers["report_msgid_bugs_to"] = report_source_bugs
 
-        # Update genric headers
+        # Update generic headers
         store.update_header(**headers)
 
         # save translation changes
@@ -1066,6 +1066,7 @@ class Translation(
         has_template = component.has_template()
         skipped = 0
         accepted = 0
+        component.start_batched_checks()
         if has_template:
             existing = set(self.unit_set.values_list("context", flat=True))
         else:
@@ -1094,7 +1095,7 @@ class Translation(
         return (0, skipped, accepted, len(store.content_units))
 
     @transaction.atomic
-    def merge_upload(
+    def handle_upload(
         self,
         request,
         fileobj: BinaryIO,
@@ -1186,7 +1187,7 @@ class Translation(
                 with component.lock:
                     return self.handle_add_upload(request, store, fuzzy=fuzzy)
 
-            # Add as sugestions
+            # Add as suggestions
             return self.merge_suggestions(request, store, fuzzy)
         finally:
             if orig_user:
@@ -1448,6 +1449,12 @@ class Translation(
                     translation.unit_set.filter(
                         position__gt=translation_unit.position
                     ).update(position=F("position") - 1)
+                # Delete stale source units
+                if not self.is_source and translation == self:
+                    source_unit = translation_unit.source_unit
+                    if source_unit.source_unit.unit_set.count() == 1:
+                        source_unit.delete()
+
             if self.is_source and unit.position and not component.has_template():
                 # Adjust position is source language
                 self.unit_set.filter(position__gt=unit.position).update(
@@ -1460,10 +1467,13 @@ class Translation(
     def sync_terminology(self):
         if not self.is_source or not self.component.manage_units:
             return
+        expected_count = self.component.translation_set.count()
         for source in self.component.get_all_sources():
             # Is the string a terminology
             if "terminology" not in source.all_flags:
                 continue
+            if source.unit_set.count() == expected_count:
+                continue
             # Add unit
             self.add_unit(
                 None,
