@@ -410,11 +410,6 @@ real_patterns = [
         weblate.trans.views.acl.create_token,
         name="create-project-token",
     ),
-    path(
-        "token/<name:project>/delete/",
-        weblate.trans.views.acl.delete_token,
-        name="delete-project-token",
-    ),
     # Used by weblate.org to reder own activity chart on homepage
     path(
         "activity/month.json",
@@ -667,6 +662,11 @@ real_patterns = [
         weblate.memory.views.DeleteView.as_view(),
         name="memory-delete",
     ),
+    path(
+        "memory/rebuild/",
+        weblate.memory.views.RebuildView.as_view(),
+        name="memory-rebuild",
+    ),
     path(
         "memory/upload/",
         weblate.memory.views.UploadView.as_view(),
@@ -695,6 +695,12 @@ real_patterns = [
         kwargs={"manage": 1},
         name="manage-memory-delete",
     ),
+    path(
+        "manage/memory/rebuild/",
+        management_access(weblate.memory.views.RebuildView.as_view()),
+        kwargs={"manage": 1},
+        name="manage-memory-rebuild",
+    ),
     path(
         "manage/memory/download/",
         management_access(weblate.memory.views.DownloadView.as_view()),
@@ -711,6 +717,11 @@ real_patterns = [
         weblate.memory.views.DeleteView.as_view(),
         name="memory-delete",
     ),
+    path(
+        "memory/project/<name:project>/rebuild/",
+        weblate.memory.views.RebuildView.as_view(),
+        name="memory-rebuild",
+    ),
     path(
         "memory/project/<name:project>/upload/",
         weblate.memory.views.UploadView.as_view(),
