@@ -47,6 +47,7 @@ SORT_KEYS = {
     "untranslated": lambda x: x.stats.todo,
     "untranslated_words": lambda x: x.stats.todo_words,
     "untranslated_chars": lambda x: x.stats.todo_chars,
+    "nottranslated": lambda x: x.stats.nottranslated,
     "checks": lambda x: x.stats.allchecks,
     "suggestions": lambda x: x.stats.suggestions,
     "comments": lambda x: x.stats.comments,
@@ -326,7 +327,7 @@ def download_translation_file(
         exporter = exporter_cls(translation=translation)
         units = translation.unit_set.prefetch_full().order_by("position")
         if query_string:
-            units = units.search(query_string).distinct()
+            units = units.search(query_string)
         exporter.add_units(units)
         response = exporter.get_response(
             "{{project}}-{0}-{{language}}.{{extension}}".format(
