@@ -21,6 +21,7 @@ import os
 
 from django.apps import AppConfig
 from django.core.checks import Warning, register
+from django.db.models.signals import post_migrate
 
 import weblate.vcs.gpg
 from weblate.utils.checks import weblate_check
@@ -28,6 +29,7 @@ from weblate.utils.data import data_dir
 from weblate.utils.lock import WeblateLock
 from weblate.vcs.base import RepositoryException
 from weblate.vcs.git import GitRepository, SubversionRepository
+from weblate.vcs.ssh import ensure_ssh_key
 
 GIT_ERRORS = []
 
@@ -102,3 +104,8 @@ class VCSConfig(AppConfig):
                 os.makedirs(configdir)
             with open(configfile, "w") as handle:
                 handle.write("*.po merge=weblate-merge-gettext-po\n")
+
+        post_migrate.connect(self.post_migrate, sender=self)
+
+    def post_migrate(self, sender, **kwargs):
+        ensure_ssh_key()
